@@ -25,11 +25,13 @@ def add_to_path(dirs):
 add_to_path([
      os.path.normpath('{{ ENV_DIR }}/lib/python2.5/site-packages'),
      os.path.normpath('{{ ENV_DIR }}/lib/python2.6/site-packages'),
-     os.path.normpath('{{ SRC_DIR }}' + '/..'),
-     '{{ SRC_DIR }}'
+     os.path.normpath('{{ ENV_DIR }}/lib/python2.7/site-packages'),
+
+     os.path.normpath('{{ PROJECT_DIR }}' + '/..'),
+     '{{ PROJECT_DIR }}',
 ])
 
-os.environ['DJANGO_SETTINGS_MODULE'] = '{{ INSTANCE_NAME }}.settings'
+os.environ['DJANGO_SETTINGS_MODULE'] = 'settings'
 
 #print sys.path
 
