@@ -14,7 +14,17 @@ __all__ = ['migrate', 'manage', 'syncdb', 'compress', 'collectstatic', 'test',
 def command_is_available(command):
     with settings(hide('warnings', 'running', 'stdout', 'stderr'), warn_only=True):
         output = run('python manage.py help ' + command)
-    return output.succeeded
+
+    if output.succeeded:
+        return True
+
+    # that's ugly
+    unknown_command_msg = "Unknown command: '%s'" % command
+    if unknown_command_msg in output:
+        return False
+
+    # re-raise the original exception
+    run('python manage.py help ' + command)
 
 @utils.inside_project
 def manage(command):
@@ -23,8 +33,9 @@ def manage(command):
 
         fab manage:createsuperuser
     """
-    if not command_is_available(command):
-        warn('Management command "%s" is not available' % command)
+    command_name = command.split()[0]
+    if not command_is_available(command_name):
+        warn('Management command "%s" is not available' % command_name)
     else:
         run('python manage.py ' + command)
 
