@@ -51,7 +51,12 @@ def mysql_install():
     os = utils.detect_os()
     system.aptitude_install('debconf-utils')
 
-    mysql_versions = {'lenny': '5.0', 'squeeze': '5.1', 'maverick': '5.1'}
+    mysql_versions = {
+        'lenny': '5.0',
+        'squeeze': '5.1',
+        'lucid': '5.1',
+        'maverick': '5.1',
+    }
     version = mysql_versions[os]
 
     debconf_defaults = [
