@@ -1,5 +1,5 @@
 from __future__ import with_statement
-from fabric.api import run, env, settings
+from fabric.api import run, env, settings, sudo
 from fab_deploy import utils
 from fab_deploy import system
 from fab_deploy import apache
@@ -8,20 +8,22 @@ from fab_deploy import apache
 __all__ = ['nginx_install', 'nginx_setup']
 
 
-@utils.run_as('root')
+@utils.run_as_sudo
 def nginx_install():
     """ Installs nginx. """
     os = utils.detect_os()
     options = {'lenny': '-t lenny-backports'}
     system.aptitude_install('nginx', options.get(os, ''))
-    run('rm -f /etc/nginx/sites-enabled/default')
+    sudo('rm -f /etc/nginx/sites-enabled/default')
 
-@utils.run_as('root')
+@utils.run_as_sudo
 def nginx_setup():
     """ Updates nginx config and restarts nginx. """
     apache._apache_setup_port()
     name = env.conf['INSTANCE_NAME']
-    utils.upload_config_template('nginx.config', '/etc/nginx/sites-available/%s' % name)
+    utils.upload_config_template('nginx.config',
+                                 '/etc/nginx/sites-available/%s' % name,
+                                 use_sudo=True)
     with settings(warn_only=True):
-        run('ln -s /etc/nginx/sites-available/%s /etc/nginx/sites-enabled/%s' % (name, name))
-    run('invoke-rc.d nginx restart')
+        sudo('ln -s /etc/nginx/sites-available/%s /etc/nginx/sites-enabled/%s' % (name, name))
+    sudo('invoke-rc.d nginx restart')
