@@ -2,7 +2,7 @@
 import sys
 from fabric.api import env, run
 from fabtest import fab, VirtualBox
-from utils import setup_ssh
+from utils import setup_ssh, setup_sudo, private_key_path
 
 from fab_deploy.utils import update_env
 from fab_deploy.system import prepare_server
@@ -21,17 +21,22 @@ def deep_prepare(name):
 
     It now prepares an extra snapshot with basic software,
     apache, nginx and mysql installed.
+
+    VM is not executed in headless mode because snapshot taking
+    seems to be broken in this mode.
     """
     env.hosts = ['foo@127.0.0.1:2222']
     env.password = '123'
     env.disable_known_hosts = True
     env.conf = {'DB_PASSWORD': '123'}
+    env.key_filename = private_key_path()
     update_env()
 
     box = VirtualBox(name)
 
     if not box.snapshot_exists('fabtest-prepared-server'):
         activate_snapshot(box, 'fabtest-initial')
+        setup_sudo()
         setup_ssh()
         fab(prepare_server)
         fab(apache_install)
